@@ -11,38 +11,46 @@ import time
 from gettext import gettext as _
 from typing import cast
 
-from gi.repository import GLib, GObject, Gtk
+from gi.repository import Gio, GLib, Gtk
 
 from lutris import settings
-from lutris.command import MonitoredCommand
 from lutris.config import LutrisConfig
 from lutris.database import categories as categories_db
 from lutris.database import games as games_db
 from lutris.database import sql
 from lutris.exception_backstops import watch_game_errors
 from lutris.exceptions import GameConfigError, InvalidGameMoveError, MissingExecutableError
+from lutris.gui.widgets import NotificationSource
+from lutris.installer import InstallationKind
+from lutris.monitored_command import MonitoredCommand
 from lutris.runner_interpreter import export_bash_script, get_launch_parameters
-from lutris.runners import InvalidRunnerError, import_runner
+from lutris.runners import import_runner, is_valid_runner_name
 from lutris.runners.runner import Runner
-from lutris.util import audio, discord, extract, jobs, linux, strings, system, xdgshortcuts
-from lutris.util.display import (
-    DISPLAY_MANAGER, SCREEN_SAVER_INHIBITOR, disable_compositing, enable_compositing, restore_gamma
-)
+from lutris.util import busy, discord, extract, jobs, linux, strings, system, xdgshortcuts
+from lutris.util.display import DISPLAY_MANAGER, SCREEN_SAVER_INHIBITOR, disable_compositing, enable_compositing
 from lutris.util.graphics.xephyr import get_xephyr_command
 from lutris.util.graphics.xrandr import turn_off_except
 from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import LOG_BUFFERS, logger
 from lutris.util.process import Process
 from lutris.util.steam.shortcut import remove_shortcut as remove_steam_shortcut
+from lutris.util.system import fix_path_case
 from lutris.util.timer import Timer
 from lutris.util.yaml import write_yaml_to_file
 
 HEARTBEAT_DELAY = 2000
 
+GAME_START = NotificationSource()
+GAME_STARTED = NotificationSource()
+GAME_STOPPED = NotificationSource()
+GAME_UPDATED = NotificationSource()
+GAME_INSTALLED = NotificationSource()
+GAME_UNHANDLED_ERROR = NotificationSource()
 
-class Game(GObject.Object):
+
+class Game:
     """This class takes cares of loading the configuration for a game
-       and running it.
+    and running it.
     """
 
     now_playing_path = os.path.join(settings.CACHE_DIR, "now-playing.txt")
@@ -53,26 +61,11 @@ class Game(GObject.Object):
 
     PRIMARY_LAUNCH_CONFIG_NAME = "(primary)"
 
-    __gsignals__ = {
-        # SIGNAL_RUN_LAST works around bug https://gitlab.gnome.org/GNOME/glib/-/issues/513
-        # fix merged Dec 2020, but we support older GNOME!
-        "game-error": (GObject.SIGNAL_RUN_LAST, bool, (object,)),
-        "game-unhandled-error": (GObject.SIGNAL_RUN_FIRST, None, (object,)),
-        "game-launch": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-start": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-started": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-stop": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-stopped": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-removed": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-updated": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-install": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-install-update": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-install-dlc": (GObject.SIGNAL_RUN_FIRST, None, ()),
-        "game-installed": (GObject.SIGNAL_RUN_FIRST, None, ()),
-    }
-
     def __init__(self, game_id: str = None):
         super().__init__()
+
+        self.game_error = NotificationSource()
+
         self._id = str(game_id) if game_id else None  # pylint: disable=invalid-name
 
         # Load attributes from database
@@ -85,7 +78,6 @@ class Game(GObject.Object):
         self.sortname = game_data.get("sortname") or ""
         self.game_config_id = game_data.get("configpath") or ""
         self.is_installed = bool(game_data.get("installed") and self.game_config_id)
-        self.is_hidden = bool(game_data.get("hidden"))
         self.platform = game_data.get("platform") or ""
         self.year = game_data.get("year") or ""
         self.lastplayed = game_data.get("lastplayed") or 0
@@ -98,8 +90,13 @@ class Game(GObject.Object):
             self.custom_images.add("coverart_big")
         self.service = game_data.get("service")
         self.appid = game_data.get("service_id")
-        self.playtime = float(game_data.get("playtime") or 0.0)
-        self.discord_id = game_data.get('discord_id')  # Discord App ID for RPC
+        try:
+            self.playtime = float(game_data.get("playtime") or 0.0)
+        except ValueError as ex:
+            logger.exception("Unable to parse playtime '%s' for game %s: %s", game_data.get("playtime"), self.slug, ex)
+            self.playtime = 0.0
+
+        self.discord_id = game_data.get("discord_id")  # Discord App ID for RPC
 
         self._config = None
         self._runner = None
@@ -147,28 +144,15 @@ class Game(GObject.Object):
             value += " (%s)" % self.runner_name
         return value
 
-    @property
-    def is_cache_managed(self):
-        """Is the DXVK cache receiving updates from lutris?"""
-        try:
-            if not self.has_runner:
-                return False
-
-            env = self.runner.system_config.get("env", {})
-            return "DXVK_STATE_CACHE_PATH" in env
-        except InvalidRunnerError as ex:
-            logger.exception("Unable to query runner configuration: %s", ex)
-            return False
-
     @property
     def id(self) -> str:
         if not self._id:
-            logger.error("The game '%s' has no ID, it is not stored in the PGA.", self.name)
+            logger.error("The game '%s' has no ID, it is not stored in the database.", self.name)
         return cast(str, self._id)
 
     @property
     def is_db_stored(self) -> bool:
-        """True if this Game has an ID, which means it is saved in the PGA."""
+        """True if this Game has an ID, which means it is saved in the database."""
         return bool(self._id)
 
     @property
@@ -176,11 +160,6 @@ class Game(GObject.Object):
         """Return whether the game can be upgraded"""
         return self.is_installed and self.service in ["gog", "itchio"]
 
-    @property
-    def is_favorite(self):
-        """Return whether the game is in the user's favorites"""
-        return "favorite" in self.get_categories()
-
     def get_categories(self):
         """Return the categories the game is in."""
         return categories_db.get_categories_in_game(self.id) if self.is_db_stored else []
@@ -193,57 +172,64 @@ class Game(GObject.Object):
         for removed_category_name in removed_category_names:
             self.remove_category(removed_category_name, no_signal=True)
 
-        self.emit("game-updated")
+        GAME_UPDATED.fire(self)
 
     def add_category(self, category_name, no_signal=False):
         """add game to category"""
         if not self.is_db_stored:
             raise RuntimeError("Games that do not have IDs cannot belong to categories.")
 
-        category = categories_db.get_category(category_name)
+        category = categories_db.get_category_by_name(category_name)
         if category is None:
             category_id = categories_db.add_category(category_name)
         else:
-            category_id = category['id']
+            category_id = category["id"]
         categories_db.add_game_to_category(self.id, category_id)
 
         if not no_signal:
-            self.emit("game-updated")
+            GAME_UPDATED.fire(self)
 
     def remove_category(self, category_name, no_signal=False):
         """remove game from category"""
-        category = categories_db.get_category(category_name)
+        if not self.is_db_stored:
+            return
+
+        category = categories_db.get_category_by_name(category_name)
         if category is None:
             return
-        category_id = category['id']
+        category_id = category["id"]
         categories_db.remove_category_from_game(self.id, category_id)
 
         if not no_signal:
-            self.emit("game-updated")
+            GAME_UPDATED.fire(self)
 
-    def add_to_favorites(self):
-        """Add the game to the 'favorite' category"""
-        if self.id is None:
-            raise RuntimeError("Games that do not have IDs cannot be favorites.")
+    @property
+    def is_favorite(self) -> bool:
+        """Return whether the game is in the user's favorites"""
+        return "favorite" in self.get_categories()
 
-        favorite = categories_db.get_category("favorite")
-        if not favorite:
-            favorite_id = categories_db.add_category("favorite")
-        else:
-            favorite_id = favorite["id"]
-        categories_db.add_game_to_category(self.id, favorite_id)
-        self.emit("game-updated")
+    def mark_as_favorite(self, is_favorite: bool) -> None:
+        """Place the game in the favorite's category, or remove it.
+        This change is applied at once, and does not need to be saved."""
+        if self.is_favorite != bool(is_favorite):
+            if is_favorite:
+                self.add_category("favorite")
+            else:
+                self.remove_category("favorite")
 
-    def remove_from_favorites(self):
-        """Remove game from favorites"""
-        favorite = categories_db.get_category("favorite")
-        categories_db.remove_category_from_game(self.id, favorite["id"])
-        self.emit("game-updated")
+    @property
+    def is_hidden(self) -> bool:
+        """Return whether the game is in the user's favorites"""
+        return ".hidden" in self.get_categories()
 
-    def set_hidden(self, is_hidden):
-        """Do not show this game in the UI"""
-        self.is_hidden = is_hidden
-        self.save()
+    def mark_as_hidden(self, is_hidden: bool) -> None:
+        """Place the game in the hidden category, or remove it.
+        This change is applied at once, and does not need to be saved."""
+        if self.is_hidden != bool(is_hidden):
+            if is_hidden:
+                self.add_category(".hidden")
+            else:
+                self.remove_category(".hidden")
 
     @property
     def log_buffer(self):
@@ -265,16 +251,16 @@ class Game(GObject.Object):
         return strings.get_formatted_playtime(self.playtime)
 
     def signal_error(self, error):
-        """Reports an error by firing game-error. If handled, it returns
-        True to indicate it handled it, and that's it. If not, this fires
-        game-unhandled-error, which is actually handled via an emission hook
-        and should not be connected otherwise.
+        """Reports an error by firing game_error. If there is no handler for this,
+        we fall back to the global GAME_UNHANDLED_ERROR.
 
         This allows special error handling to be set up for a particular Game, but
-        there's always some handling."""
-        handled = self.emit("game-error", error)
-        if not handled:
-            self.emit("game-unhandled-error", error)
+        there's always some global handling."""
+
+        if self.game_error.has_handlers:
+            self.game_error.fire(error)
+        else:
+            GAME_UNHANDLED_ERROR.fire(self, error)
 
     def get_browse_dir(self):
         """Return the path to open with the Browse Files action."""
@@ -322,7 +308,7 @@ class Game(GObject.Object):
 
     @property
     def has_runner(self) -> bool:
-        return bool(self._runner_name)
+        return bool(self._runner_name and is_valid_runner_name(self._runner_name))
 
     @property
     def runner(self) -> Runner:
@@ -351,27 +337,82 @@ class Game(GObject.Object):
                 disable_compositing()
                 self.compositor_disabled = True
 
-    def remove(self, delete_files: bool = False, no_signal: bool = False) -> None:
-        """Uninstall a game, and removes it from the library if this it has no playtime.
+    def install(self, launch_ui_delegate):
+        """Request installation of a game"""
+        if not self.slug:
+            raise ValueError("Invalid game passed: %s" % self)
 
-        Params:
-            delete_files (bool): Delete the game files
-            no_signal (bool): Don't emit game-removed signal
-        """
-        if self.playtime:
-            self.uninstall(delete_files=delete_files, no_signal=no_signal)
-        else:
-            self.uninstall(delete_files=delete_files, no_signal=True)
-            self.delete(no_signal=no_signal)
+        if not self.service or self.service == "lutris":
+            application = Gio.Application.get_default()
+            application.show_lutris_installer_window(game_slug=self.slug)
+            return
 
-    def uninstall(self, delete_files: bool = False, no_signal: bool = False) -> None:
+        service = launch_ui_delegate.get_service(self.service)
+        db_game = service.get_service_db_game(self)
+        if not db_game:
+            logger.error("Can't find %s for %s, trying to fall back to Lutris installers", self.name, service.name)
+            application = Gio.Application.get_default()
+            application.show_lutris_installer_window(game_slug=self.slug)
+            return
+
+        try:
+            game_id = service.install(db_game)
+        except ValueError as e:
+            logger.debug(e)
+            game_id = None
+
+        if game_id:
+
+            def on_error(error: BaseException) -> None:
+                logger.exception("Unable to install game: %s", error)
+
+            game = Game(game_id)
+            game.game_error.register(on_error)
+            game.launch(launch_ui_delegate)
+
+    def install_updates(self, install_ui_delegate):
+        service = install_ui_delegate.get_service(self.service)
+        db_game = games_db.get_game_by_field(self.id, "id")
+
+        def on_installers_ready(installers, error):
+            if error:
+                raise error  # bounce errors off the backstop
+
+            if not installers:
+                raise RuntimeError(_("No updates found"))
+
+            application = Gio.Application.get_default()
+            application.show_installer_window(
+                installers, service, self.appid, installation_kind=InstallationKind.UPDATE
+            )
+
+        busy.BusyAsyncCall(service.get_update_installers, on_installers_ready, db_game)
+        return True
+
+    def install_dlc(self, install_ui_delegate):
+        service = install_ui_delegate.get_service(self.service)
+        db_game = games_db.get_game_by_field(self.id, "id")
+
+        def on_installers_ready(installers, error):
+            if error:
+                raise error  # bounce errors off the backstop
+
+            if not installers:
+                raise RuntimeError(_("No DLC found"))
+
+            application = Gio.Application.get_default()
+            application.show_installer_window(installers, service, self.appid, installation_kind=InstallationKind.DLC)
+
+        busy.BusyAsyncCall(service.get_dlc_installers_runner, on_installers_ready, db_game, db_game["runner"])
+        return True
+
+    def uninstall(self, delete_files: bool = False) -> None:
         """Uninstall a game, but do not remove it from the library.
 
         Params:
             delete_files (bool): Delete the game files
-            no_signal (bool): Don't emit game-removed signal
         """
-        sql.db_update(settings.PGA_DB, "games", {"installed": 0, "runner": ""}, {"id": self.id})
+        sql.db_update(settings.DB_PATH, "games", {"installed": 0, "runner": ""}, {"id": self.id})
         if self.config:
             self.config.remove()
         xdgshortcuts.remove_launcher(self.slug, self.id, desktop=True, menu=True)
@@ -388,16 +429,11 @@ class Game(GObject.Object):
             log_buffer = LOG_BUFFERS[self.id]
             log_buffer.delete(log_buffer.get_start_iter(), log_buffer.get_end_iter())
 
-        if not no_signal:
-            self.emit("game-removed")
-
-    def delete(self, no_signal: bool = False) -> None:
+    def delete(self) -> None:
         """Delete a game from the library; must be uninstalled first."""
         if self.is_installed:
             raise RuntimeError(_("Uninstall the game before deleting"))
         games_db.delete_game(self.id)
-        if not no_signal:
-            self.emit("game-removed")
         self._id = None
 
     def set_platform_from_runner(self):
@@ -435,34 +471,28 @@ class Game(GObject.Object):
             "configpath": configpath,
             "id": self.id,
             "playtime": self.playtime,
-            "hidden": self.is_hidden,
             "service": self.service,
             "service_id": self.appid,
             "discord_id": self.discord_id,
             "has_custom_banner": "banner" in self.custom_images,
             "has_custom_icon": "icon" in self.custom_images,
-            "has_custom_coverart_big": "coverart_big" in self.custom_images
+            "has_custom_coverart_big": "coverart_big" in self.custom_images,
         }
         self._id = str(games_db.add_or_update(**game_data))
         if not no_signal:
-            self.emit("game-updated")
+            GAME_UPDATED.fire(self)
 
     def save_platform(self):
         """Save only the platform field- do not restore any other values the user may have changed
         in another window."""
         games_db.update_existing(id=self.id, slug=self.slug, platform=self.platform)
-        self.emit("game-updated")
+        GAME_UPDATED.fire(self)
 
     def save_lastplayed(self):
         """Save only the lastplayed field- do not restore any other values the user may have changed
         in another window."""
-        games_db.update_existing(
-            id=self.id,
-            slug=self.slug,
-            lastplayed=self.lastplayed,
-            playtime=self.playtime
-        )
-        self.emit("game-updated")
+        games_db.update_existing(id=self.id, slug=self.slug, lastplayed=self.lastplayed, playtime=self.playtime)
+        GAME_UPDATED.fire(self)
 
     def check_launchable(self):
         """Verify that the current game can be launched, and raises exceptions if not."""
@@ -515,7 +545,7 @@ class Game(GObject.Object):
             antimicro_command = ["flatpak-spawn", "--host", "antimicrox"]
         else:
             try:
-                antimicro_command = [system.find_executable("antimicrox")]
+                antimicro_command = [system.find_required_executable("antimicrox")]
             except MissingExecutableError as ex:
                 raise GameConfigError(
                     _("Unable to find Antimicrox, install it or disable the Antimicrox option")
@@ -593,16 +623,64 @@ class Game(GObject.Object):
 
         return gameplay_info
 
+    def get_path_from_config(self):
+        """Return the path of the main entry point for a game"""
+        if not self.config:
+            logger.warning("%s has no configuration", self)
+            return ""
+        game_config = self.config.game_config
+
+        # Skip MAME roms referenced by their ID
+        if self.runner_name == "mame":
+            if "main_file" in game_config and "." not in game_config["main_file"]:
+                return ""
+
+        for key in ["exe", "main_file", "iso", "rom", "disk-a", "path", "files"]:
+            if key in game_config:
+                path = game_config[key]
+                if key == "files":
+                    path = path[0]
+
+                if path:
+                    path = os.path.expanduser(path)
+                    if not path.startswith("/"):
+                        path = os.path.join(self.directory, path)
+
+                    # The Wine runner fixes case mismatches automatically,
+                    # sort of like Windows, so we need to do the same.
+                    if self.runner_name == "wine":
+                        path = fix_path_case(path)
+
+                    return path
+
+        logger.warning("No path found in %s", self.config)
+        return ""
+
+    def get_store_name(self) -> str:
+        store = self.service
+        if not store:
+            return "none"
+        if self.service == "humblebundle":
+            return "humble"
+        return store
+
     @watch_game_errors(game_stop_result=False)
     def configure_game(self, launch_ui_delegate):
         """Get the game ready to start, applying all the options.
         This method sets the game_runtime_config attribute.
         """
         gameplay_info = self.get_gameplay_info(launch_ui_delegate)
-        if not gameplay_info:  # if user cancelled- not an error
+        if not gameplay_info:  # if user cancelled - not an error
             return False
         command, env = get_launch_parameters(self.runner, gameplay_info)
-        env["game_name"] = self.name  # What is this used for??
+
+        env["STORE"] = env.get("STORE") or self.get_store_name()
+
+        # Some environment variables for the use of custom pre-launch and post-exit scripts.
+        env["GAME_NAME"] = self.name
+        if self.directory:
+            env["GAME_DIRECTORY"] = self.directory
+
         self.game_runtime_config = {
             "args": command,
             "env": env,
@@ -614,10 +692,6 @@ class Game(GObject.Object):
         if "working_dir" in gameplay_info:
             self.game_runtime_config["working_dir"] = gameplay_info["working_dir"]
 
-        # Audio control
-        if self.runner.system_config.get("reset_pulse"):
-            audio.reset_pulse()
-
         # Input control
         if self.runner.system_config.get("use_us_layout"):
             system.set_keyboard_layout("us")
@@ -644,6 +718,8 @@ class Game(GObject.Object):
         if xephyr != "off":
             env["DISPLAY"] = self.start_xephyr()
 
+        self.runner.finish_env(env, self)
+
         antimicro_config = self.runner.system_config.get("antimicro_config")
         if system.path_exists(antimicro_config):
             self.start_antimicrox(antimicro_config)
@@ -680,7 +756,7 @@ class Game(GObject.Object):
             logger.error("No prelaunch PIDs could be obtained. Game stop may be ineffective.")
             self.prelaunch_pids = None
 
-        self.emit("game-start")
+        GAME_START.fire(self)
 
         @watch_game_errors(game_stop_result=False, game=self)
         def configure_game(_ignored, error):
@@ -710,10 +786,10 @@ class Game(GObject.Object):
         self.game_thread.start()
         self.timer.start()
         self.state = self.STATE_RUNNING
-        self.emit("game-started")
+        GAME_STARTED.fire(self)
 
         # Game is running, let's update discord status
-        if settings.read_setting('discord_rpc') == 'True' and self.discord_id:
+        if settings.read_setting("discord_rpc") == "True" and self.discord_id:
             try:
                 discord.client.update(self.discord_id)
             except AssertionError:
@@ -738,9 +814,9 @@ class Game(GObject.Object):
             else:
                 self.force_kill_delayed()
 
-        jobs.AsyncCall(force_stop_game, force_stop_game_cb)
+        busy.BusyAsyncCall(force_stop_game, force_stop_game_cb)
 
-    def force_kill_delayed(self, death_watch_seconds=5, death_watch_interval_seconds=.5):
+    def force_kill_delayed(self, death_watch_seconds=5, death_watch_interval_seconds=0.5):
         """Forces termination of a running game, but only after a set time has elapsed;
         Invokes stop_game() when the game is dead."""
 
@@ -762,7 +838,7 @@ class Game(GObject.Object):
             # If we still can't kill everything, we'll still say we stopped it.
             self.stop_game()
 
-        jobs.AsyncCall(death_watch, death_watch_cb)
+        busy.BusyAsyncCall(death_watch, death_watch_cb)
 
     def kill_processes(self, sig):
         """Sends a signal to a process list, logging errors."""
@@ -800,9 +876,7 @@ class Game(GObject.Object):
             if game_folder in cmdline or "pressure-vessel" in cmdline:
                 folder_pids.add(pid)
 
-        uuid_pids = set(
-            pid for pid in new_pids
-            if Process(pid).environ.get("LUTRIS_GAME_UUID") == self.game_uuid)
+        uuid_pids = set(pid for pid in new_pids if Process(pid).environ.get("LUTRIS_GAME_UUID") == self.game_uuid)
 
         return folder_pids & uuid_pids
 
@@ -817,13 +891,13 @@ class Game(GObject.Object):
     def stop_game(self):
         """Cleanup after a game as stopped"""
         duration = self.timer.duration
-        logger.debug("%s has run for %s seconds", self, duration)
+        logger.debug("%s has run for %d seconds", self, duration)
         if duration < 5:
             logger.warning("The game has run for a very short time, did it crash?")
             # Inspect why it could have crashed
 
         self.state = self.STATE_STOPPED
-        self.emit("game-stop")
+        GAME_STOPPED.fire(self)
         if os.path.exists(self.now_playing_path):
             os.unlink(self.now_playing_path)
         if not self.timer.finished:
@@ -864,6 +938,7 @@ class Game(GObject.Object):
         logger.info("Stopping %s", self)
 
         if self.game_thread:
+
             def stop_cb(_result, error):
                 if error:
                     self.signal_error(error)
@@ -924,12 +999,13 @@ class Game(GObject.Object):
             with subprocess.Popen(["setxkbmap"], env=os.environ) as setxkbmap:
                 setxkbmap.communicate()
 
-        if self.runner.system_config.get("restore_gamma"):
-            restore_gamma()
-
         # Clear Discord Client Status
-        if settings.read_setting('discord_rpc') == 'True' and self.discord_id:
-            discord.client.clear()
+        if settings.read_setting("discord_rpc") == "True" and self.discord_id:
+            try:
+                discord.client.clear()
+            except:
+                # Shut up no one cares about you or your errors
+                pass
 
         self.process_return_codes()
 
@@ -962,36 +1038,41 @@ class Game(GObject.Object):
         old_location = self.directory
         target_directory = self._get_move_target_directory(new_location)
 
-        # Raise errors before actually changing anything!
-        if not old_location:
-            raise InvalidGameMoveError(_("The game has no location currently set, so it can't be moved."))
-
-        if not system.path_exists(old_location):
+        if old_location and system.path_contains(old_location, new_location):
             raise InvalidGameMoveError(
-                _("The location '%s' does not exist, perhaps the files have already been moved?") % old_location)
-
-        if new_location.startswith(old_location):
-            raise InvalidGameMoveError(
-                _("Lutris can't move '%s' to a location inside of itself, '%s'.") % (old_location, new_location))
+                _("Lutris can't move '%s' to a location inside of itself, '%s'.") % (old_location, new_location)
+            )
 
         self.directory = target_directory
         self.save(no_signal=no_signal)
 
-        with open(self.config.game_config_path, encoding='utf-8') as config_file:
+        if not old_location:
+            # We can't move or update the config without an initial
+            # location, but no-one expects us to. We've just updated
+            # the game directory, and that will do.
+            return target_directory
+
+        with open(self.config.game_config_path, encoding="utf-8") as config_file:
             for line in config_file.readlines():
                 if target_directory in line:
                     new_config += line
                 else:
                     new_config += line.replace(old_location, target_directory)
-        with open(self.config.game_config_path, "w", encoding='utf-8') as config_file:
+        with open(self.config.game_config_path, "w", encoding="utf-8") as config_file:
             config_file.write(new_config)
 
+        if not system.path_exists(old_location):
+            logger.warning("Initial location %s does not exist, files may have already been moved.")
+            return target_directory
+
         try:
             shutil.move(old_location, new_location)
         except OSError as ex:
             logger.error(
                 "Failed to move %s to %s, you may have to move files manually (Exception: %s)",
-                old_location, new_location, ex
+                old_location,
+                new_location,
+                ex,
             )
         return target_directory
 
@@ -1039,10 +1120,7 @@ def export_game(slug, dest_dir):
         json.dump(db_game, config_file, indent=2)
     archive_path = os.path.join(dest_dir, "%s.tar.xz" % slug)
     command = ["tar", "cJf", archive_path, os.path.basename(game_path)]
-    system.execute(
-        command,
-        cwd=os.path.dirname(game_path)
-    )
+    system.execute(command, cwd=os.path.dirname(game_path))
     logger.info("%s exported to %s", slug, archive_path)
 
 
@@ -1067,10 +1145,10 @@ def import_game(file_path, dest_dir):
     with open(os.path.join(game_dir, game_config), encoding="utf-8") as config_file:
         lutris_config = json.load(config_file)
     old_dir = lutris_config["directory"]
-    with open(os.path.join(game_dir, game_config), 'r', encoding="utf-8") as config_file:
+    with open(os.path.join(game_dir, game_config), "r", encoding="utf-8") as config_file:
         config_data = config_file.read()
     config_data = config_data.replace(old_dir, game_dir)
-    with open(os.path.join(game_dir, game_config), 'w', encoding="utf-8") as config_file:
+    with open(os.path.join(game_dir, game_config), "w", encoding="utf-8") as config_file:
         config_file.write(config_data)
     with open(os.path.join(game_dir, game_config), encoding="utf-8") as config_file:
         lutris_config = json.load(config_file)
@@ -1087,7 +1165,6 @@ def import_game(file_path, dest_dir):
         lastplayed=lutris_config["lastplayed"],
         configpath=lutris_config["configpath"],
         playtime=lutris_config["playtime"],
-        hidden=lutris_config["hidden"],
         service=lutris_config["service"],
         service_id=lutris_config["service_id"],
     )
