@@ -10,11 +10,11 @@ from gi.repository import GdkPixbuf, Gtk, Pango
 from lutris import runners, settings
 from lutris.config import LutrisConfig, make_game_config_id
 from lutris.game import Game
-from lutris.gui import dialogs
 from lutris.gui.config import DIALOG_HEIGHT, DIALOG_WIDTH
 from lutris.gui.config.boxes import GameBox, RunnerBox, SystemConfigBox, UnderslungMessageBox
-from lutris.gui.dialogs import DirectoryDialog, ErrorDialog, QuestionDialog, SavableModelessDialog
+from lutris.gui.dialogs import DirectoryDialog, ErrorDialog, QuestionDialog, SavableModelessDialog, display_error
 from lutris.gui.dialogs.delegates import DialogInstallUIDelegate
+from lutris.gui.dialogs.move_game import MoveDialog
 from lutris.gui.widgets.common import Label, NumberEntry, SlugEntry
 from lutris.gui.widgets.notifications import send_notification
 from lutris.gui.widgets.scaled_image import ScaledImage
@@ -68,6 +68,7 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
         self.lutris_config = None
         self.service_medias = {"icon": LutrisIcon(), "banner": LutrisBanner(), "coverart_big": LutrisCoverart()}
         self.notebook_page_generators = {}
+        self.notebook_page_updater = {}
 
         self.build_header_bar()
 
@@ -90,6 +91,10 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
         if generator:
             generator()
             del self.notebook_page_generators[index]
+        else:
+            updater = self.notebook_page_updater.get(index)
+            if updater:
+                updater()
 
         self.update_advanced_switch_visibility(index)
         self.update_search_entry_visibility(index)
@@ -123,12 +128,13 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
             show_search = current_page_index in self.searchable_page_indices
             self.set_search_entry_visibility(show_search)
 
-    def set_search_entry_visibility(self, show_search, placeholder_text=None):
+    def set_search_entry_visibility(self, show_search, placeholder_text=None, tooltip_markup=None):
         """Explicitly shows or hides the search entry; can also update the placeholder text."""
         header_bar = self.get_header_bar()
         if show_search and self.search_entry:
             header_bar.set_custom_title(self.search_entry)
             self.search_entry.set_placeholder_text(placeholder_text or self.get_search_entry_placeholder())
+            self.search_entry.set_tooltip_markup(tooltip_markup)
         else:
             header_bar.set_custom_title(None)
 
@@ -347,8 +353,13 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
         service_media = self.service_medias[image_format]
         game_slug = self.slug or (self.game.slug if self.game else "")
         media_path = resolve_media_path(service_media.get_possible_media_paths(game_slug))
-        image = ScaledImage.new_from_media_path(media_path, service_media.config_ui_size, scale_factor)
-        image_button.set_image(image)
+        try:
+            image = ScaledImage.new_from_media_path(media_path, service_media.config_ui_size, scale_factor)
+            image_button.set_image(image)
+        except Exception as ex:
+            # We need to survive nasty data in the media files, so the user can replace
+            # them.
+            logger.exception("Unable to load media '%s': %s", image_format, ex)
 
     def _get_runner_dropdown(self):
         runner_liststore = self._get_runner_liststore()
@@ -406,7 +417,7 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
         )
         if not new_location.folder or new_location.folder == self.game.directory:
             return
-        move_dialog = dialogs.MoveDialog(self.game, new_location.folder, parent=self)
+        move_dialog = MoveDialog(self.game, new_location.folder, parent=self)
         move_dialog.connect("game-moved", self.on_game_moved)
         move_dialog.move()
 
@@ -472,6 +483,8 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
         config_box = box_factory()
         page_index = self._add_notebook_tab(self.build_scrolled_window(config_box), notebook_label)
 
+        self.notebook_page_updater[page_index] = config_box.update_warnings
+
         if page_index == 0:
             config_box.generate_widgets()
         else:
@@ -620,11 +633,11 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
             ErrorDialog(_("Steam AppID not provided"), parent=self)
             return False
         playtime_text = self.playtime_entry.get_text()
-        if playtime_text and playtime_text != self.game.formatted_playtime:
+        if playtime_text and (not self.game or playtime_text != self.game.formatted_playtime):
             try:
                 parse_playtime(playtime_text)
             except ValueError as ex:
-                ErrorDialog(ex, parent=self)
+                display_error(ex, parent=self)
                 return False
 
         invalid_fields = []
@@ -714,7 +727,7 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
     def on_custom_image_reset_clicked(self, _widget, image_type):
         self.refresh_image(image_type)
 
-    def save_custom_media(self, image_type, image_path):
+    def save_custom_media(self, image_type: str, image_path: str) -> None:
         slug = self.slug or self.game.slug
         service_media = self.service_medias[image_type]
         self.game.custom_images.add(image_type)
@@ -731,7 +744,7 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
 
             self._save_transcoded_media_to(dest_paths[0], image_type, image_path)
 
-    def _save_copied_media_to(self, dest_path, image_type, image_path):
+    def _save_copied_media_to(self, dest_path: str, image_type: str, image_path: str) -> None:
         """Copies a media file to the dest_path, but trashes the existing media
         for the game first. When complete, this updates the button indicated by
         image_type as well."""
@@ -748,14 +761,15 @@ class GameDialogCommon(SavableModelessDialog, DialogInstallUIDelegate):
 
         service_media.trash_media(slug, completion_function=on_trashed)
 
-    def _save_transcoded_media_to(self, dest_path, image_type, image_path):
+    def _save_transcoded_media_to(self, dest_path: str, image_type: str, image_path: str) -> None:
         """Transcode an image, copying it to a new path and selecting the file type
         based on the file extension of dest_path. Trashes all media for the current
         game too. Runs in the background, and when complete updates the button indicated
         by image_type."""
         slug = self.slug or self.game.slug
         service_media = self.service_medias[image_type]
-        file_format = {".jpg": "jpeg", ".png": "png"}[get_image_file_extension(dest_path)]
+        ext = get_image_file_extension(dest_path) or ".png"
+        file_format = {".jpg": "jpeg", ".png": "png"}[ext]
 
         # If we must transcode the image, we'll scale the image up based on
         # the UI scale factor, to try to avoid blurriness. Of course this won't
