@@ -1,6 +1,6 @@
 """Lutris installer class"""
+
 import json
-import os
 from gettext import gettext as _
 
 from lutris.config import LutrisConfig, write_game_config
@@ -9,7 +9,6 @@ from lutris.exceptions import UnavailableGameError
 from lutris.installer import AUTO_ELF_EXE, AUTO_WIN32_EXE
 from lutris.installer.errors import ScriptingError
 from lutris.installer.installer_file import InstallerFile
-from lutris.installer.legacy import get_game_launcher
 from lutris.runners import import_runner
 from lutris.services import SERVICES
 from lutris.util.game_finder import find_linux_game_executable, find_windows_game_executable
@@ -47,7 +46,7 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
         self.extends = self.script.get("extends")
         self.game_id = self.get_game_id()
         self.is_gog = False
-        self.discord_id = installer.get('discord_id')
+        self.discord_id = installer.get("discord_id")
 
     def get_service(self, initial=None):
         if initial:
@@ -108,14 +107,9 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
         if not self.script.get("installer"):
             # No command can affect files
             return False
-        if (
-            self.script_files
-            or self.script.get("game", {}).get("gog")
-            or self.script.get("game", {}).get("prefix")
-        ):
+        if self.script_files or self.script.get("game", {}).get("gog") or self.script.get("game", {}).get("prefix"):
             return True
-        command_names = [self.interpreter._get_command_name_and_params(c)[0]
-                         for c in self.script.get("installer", [])]
+        command_names = [self.interpreter._get_command_name_and_params(c)[0] for c in self.script.get("installer", [])]
         if "insert_disc" in command_names:
             return True
         return False
@@ -190,10 +184,9 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
             else:
                 # Failed to get the service game, put back a user provided file
                 logger.debug("Unable to get files from service. Setting %s to manual.", installer_file_id)
-                files.insert(0, InstallerFile(self.game_slug, installer_file_id, {
-                    "url": installer_file_url,
-                    "filename": ""
-                }))
+                files.insert(
+                    0, InstallerFile(self.game_slug, installer_file_id, {"url": installer_file_url, "filename": ""})
+                )
 
         # Commit changes only at the end; this is more robust in this method is runner
         # my two threads concurrently- the GIL can probably save us. It's not desirable
@@ -210,9 +203,7 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
             self.script["installer"] = []
 
         for extra_file in self.extra_file_paths:
-            self.script["installer"].append(
-                {"copy": {"src": extra_file, "dst": "$GAMEDIR/extras"}}
-            )
+            self.script["installer"].append({"copy": {"src": extra_file, "dst": "$GAMEDIR/extras"}})
 
     def _substitute_config(self, script_config):
         """Substitute values such as $GAMEDIR in a config dict."""
@@ -221,15 +212,12 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
             if not isinstance(key, str):
                 raise ScriptingError(_("Game config key must be a string"), key)
             value = script_config[key]
-            if str(value).lower() == 'true':
+            if str(value).lower() == "true":
                 value = True
-            if str(value).lower() == 'false':
+            if str(value).lower() == "false":
                 value = False
             if key == "launch_configs":
-                config[key] = [
-                    {k: self.interpreter._substitute(v) for (k, v) in _conf.items()}
-                    for _conf in value
-                ]
+                config[key] = [{k: self.interpreter._substitute(v) for (k, v) in _conf.items()} for _conf in value]
             elif isinstance(value, list):
                 config[key] = [self.interpreter._substitute(i) for i in value]
             elif isinstance(value, dict):
@@ -249,9 +237,7 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
                 required_game = get_game_by_field(self.requires, field="slug")
             if not required_game:
                 raise ValueError("No game matched '%s' on installer_slug or slug" % self.requires)
-            base_config = LutrisConfig(
-                runner_slug=self.runner, game_config_id=required_game["configpath"]
-            )
+            base_config = LutrisConfig(runner_slug=self.runner, game_config_id=required_game["configpath"])
             config = base_config.game_level
         else:
             config = {"game": {}}
@@ -259,28 +245,43 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
         # Config update
         if "system" in self.script:
             config["system"] = self._substitute_config(self.script["system"])
-        if self.runner in self.script and self.script[self.runner]:
-            config[self.runner] = self._substitute_config(self.script[self.runner])
-        launcher, launcher_config = self.get_game_launcher_config(self.interpreter.game_files)
-        if launcher:
-            config["game"][launcher] = launcher_config
+        if self.script.get(self.runner):
+            installer_runner_config = self._substitute_config(self.script[self.runner])
+            import_runner(self.runner)().adjust_installer_runner_config(installer_runner_config)
+            config[self.runner] = installer_runner_config
+
+        game_config = config["game"]
+
+        entry_point_keys = ("iso", "rom", "main_file", "exe")
 
         if "game" in self.script:
             try:
-                config["game"].update(self.script["game"])
+                game_config.update(self.script["game"])
             except ValueError as err:
                 raise ScriptingError(_("Invalid 'game' section"), self.script["game"]) from err
-            config["game"] = self._substitute_config(config["game"])
-            if AUTO_ELF_EXE in config["game"].get("exe", ""):
-                config["game"]["exe"] = find_linux_game_executable(self.interpreter.target_path,
-                                                                   make_executable=True)
-            elif AUTO_WIN32_EXE in config["game"].get("exe", ""):
-                config["game"]["exe"] = find_windows_game_executable(self.interpreter.target_path)
 
-            # Fix possible case differences
-            for key in ("iso", "rom", "main_file", "exe"):
-                if config["game"].get(key):
-                    config["game"][key] = fix_path_case(config["game"][key])
+        # Obsolete install scripts may have the entry point key at root level;
+        # we'll move them into the game-config if so, and if they are not already
+        # there. Add a warning because I'm sure this compatibility ship will get lost,
+        # and the scripts would be better updated.
+        for entry_point_key in entry_point_keys:
+            if entry_point_key in self.script and entry_point_key not in game_config:
+                logger.warning("Moving entry point '%s' from script root level to the game config", entry_point_key)
+                game_config[entry_point_key] = self.script[entry_point_key]
+
+        game_config = self._substitute_config(game_config)
+        if AUTO_ELF_EXE in game_config.get("exe", ""):
+            game_config["exe"] = find_linux_game_executable(self.interpreter.target_path, make_executable=True)
+        elif AUTO_WIN32_EXE in game_config.get("exe", ""):
+            game_config["exe"] = find_windows_game_executable(self.interpreter.target_path)
+
+        # Fix possible case differences
+        for key in entry_point_keys:
+            entry_point = game_config.get(key)
+            if entry_point:
+                game_config[key] = fix_path_case(entry_point)
+
+        config["game"] = game_config
         config["name"] = self.game_name
         config["script"] = self.script
         config["variables"] = self.variables
@@ -311,49 +312,20 @@ class LutrisInstaller:  # pylint: disable=too-many-instance-attributes
                 self.script["game"].update(lutris_config)
 
         configpath = write_game_config(self.slug, self.get_game_config())
-        runner_inst = import_runner(self.runner)()
-        if self.service:
-            service_id = self.service.id
-        else:
-            service_id = None
         self.game_id = add_or_update(
             name=self.game_name,
             runner=self.runner,
             slug=self.game_slug,
-            platform=runner_inst.get_platform(),
+            platform=import_runner(self.runner)().get_platform(),
             directory=self.interpreter.target_path,
             installed=1,
-            hidden=0,
             installer_slug=self.slug,
             parent_slug=self.requires,
             year=self.year,
             configpath=configpath,
-            service=service_id,
+            service=self.service.id if self.service else None,
             service_id=self.service_appid,
             id=self.game_id,
             discord_id=self.discord_id,
         )
         return self.game_id
-
-    def get_game_launcher_config(self, game_files):
-        """Game options such as exe or main_file can be added at the root of the
-        script as a shortcut, this integrates them into the game config properly
-        This should be deprecated. Game launchers should go in the game section.
-        """
-        launcher, launcher_value = get_game_launcher(self.script)
-        if isinstance(launcher_value, list):
-            launcher_values = []
-            for game_file in launcher_value:
-                if game_file in game_files:
-                    launcher_values.append(game_files[game_file])
-                else:
-                    launcher_values.append(game_file)
-            return launcher, launcher_values
-        if launcher_value:
-            if launcher_value in game_files:
-                launcher_value = game_files[launcher_value]
-            elif self.interpreter.target_path and os.path.exists(
-                os.path.join(self.interpreter.target_path, launcher_value)
-            ):
-                launcher_value = os.path.join(self.interpreter.target_path, launcher_value)
-        return launcher, launcher_value
