@@ -3,6 +3,7 @@ from gettext import gettext as _
 from os import path
 
 from lutris.exceptions import DirectoryNotFoundError, GameConfigError, MissingGameExecutableError
+
 # Lutris Modules
 from lutris.runners.runner import Runner
 
@@ -21,7 +22,7 @@ class easyrpg(Runner):
             "option": "project_path",
             "type": "directory_chooser",
             "label": _("Game directory"),
-            "help": _("Select the directory of the game. <b>(required)</b>")
+            "help": _("Select the directory of the game. <b>(required)</b>"),
         },
         {
             "option": "encoding",
@@ -49,7 +50,7 @@ class easyrpg(Runner):
                 (_("Baltic"), "1257"),
                 (_("Thai"), "874"),
             ],
-            "default": ""
+            "default": "",
         },
         {
             "option": "engine",
@@ -66,7 +67,7 @@ class easyrpg(Runner):
                 (_("RPG Maker 2003 engine (v1.05 - v1.09a)"), "rpg2k3v105"),
                 (_("RPG Maker 2003 (English release) engine"), "rpg2k3e"),
             ],
-            "default": ""
+            "default": "",
         },
         {
             "option": "patch",
@@ -76,23 +77,21 @@ class easyrpg(Runner):
             "help": _(
                 "Instead of autodetecting patches used by this game, force emulation of certain patches.\n"
                 "\nAvailable patches:\n"
-                "<b>common-this</b>: \"This Event\" in common events"
+                '<b>common-this</b>: "This Event" in common events'
                 "<b>dynrpg</b>: DynRPG patch by Cherry"
                 "<b>key-patch</b>: Key Patch by Ineluki"
                 "<b>maniac</b>: Maniac Patch by BingShan"
                 "<b>pic-unlock</b>: Pictures are not blocked by messages"
                 "<b>rpg2k3-cmds</b>: Support all RPG Maker 2003 event commands in any version of the engine"
                 "\n\nYou can provide multiple patches or use 'none' to disable all engine patches."
-            )
+            ),
         },
         {
             "option": "language",
             "type": "string",
             "advanced": True,
             "label": _("Language"),
-            "help": _(
-                "Load the game translation in the language/LANG directory."
-            ),
+            "help": _("Load the game translation in the language/LANG directory."),
         },
         {
             "option": "save_path",
@@ -102,33 +101,30 @@ class easyrpg(Runner):
             "help": _(
                 "Instead of storing save files in the game directory they are stored in the specified path. "
                 "The directory must exist."
-            )
+            ),
         },
         {
             "option": "new_game",
             "type": "bool",
             "label": _("New game"),
             "help": _("Skip the title scene and start a new game directly."),
-            "default": False
+            "default": False,
         },
         {
             "option": "load_game_id",
             "type": "range",
             "label": _("Load game ID"),
-            "help": _(
-                "Skip the title scene and load SaveXX.lsd.\n"
-                "Set to 0 to disable."
-            ),
+            "help": _("Skip the title scene and load SaveXX.lsd.\n" "Set to 0 to disable."),
             "min": 0,
             "max": 99,
-            "default": 0
+            "default": 0,
         },
         {
             "option": "record_input",
             "type": "file",
             "advanced": True,
             "label": _("Record input"),
-            "help": _("Records all button input to the specified log file.")
+            "help": _("Records all button input to the specified log file."),
         },
         {
             "option": "replay_input",
@@ -139,7 +135,7 @@ class easyrpg(Runner):
                 "Replays button input from the specified log file, as generated by 'Record input'.\n"
                 "If the RNG seed and the state of the save file directory is also the same as it was "
                 "when the log was recorded, this should reproduce an identical run to the one recorded."
-            )
+            ),
         },
         {
             "option": "test_play",
@@ -148,7 +144,7 @@ class easyrpg(Runner):
             "section": _("Debug"),
             "label": _("Test play"),
             "help": _("Enable TestPlay (debug) mode."),
-            "default": False
+            "default": False,
         },
         {
             "option": "hide_title",
@@ -157,7 +153,7 @@ class easyrpg(Runner):
             "section": _("Debug"),
             "label": _("Hide title"),
             "help": _("Hide the title background image and center the command menu."),
-            "default": False
+            "default": False,
         },
         {
             "option": "start_map_id",
@@ -172,7 +168,7 @@ class easyrpg(Runner):
             ),
             "min": 0,
             "max": 9999,
-            "default": 0
+            "default": 0,
         },
         {
             "option": "start_position",
@@ -184,7 +180,7 @@ class easyrpg(Runner):
                 "Overwrite the party start position and move the party to the specified position.\n"
                 "Provide two numbers separated by a space.\n\n"
                 "Incompatible with 'Load game ID'."
-            )
+            ),
         },
         {
             "option": "start_party",
@@ -196,7 +192,7 @@ class easyrpg(Runner):
                 "Overwrite the starting party members with the actors with the specified IDs.\n"
                 "Provide one to four numbers separated by spaces.\n\n"
                 "Incompatible with 'Load game ID'."
-            )
+            ),
         },
         {
             "option": "battle_test",
@@ -204,8 +200,8 @@ class easyrpg(Runner):
             "advanced": True,
             "section": _("Debug"),
             "label": _("Battle test"),
-            "help": _("Start a battle test with the specified monster party.")
-        }
+            "help": _("Start a battle test with the specified monster party."),
+        },
     ]
 
     runner_options = [
@@ -227,7 +223,7 @@ class easyrpg(Runner):
                 (_("RPG_RT+"), "RPG_RT+"),
                 (_("ATTACK"), "ATTACK"),
             ],
-            "default": ""
+            "default": "",
         },
         {
             "option": "enemyai_algo",
@@ -245,7 +241,7 @@ class easyrpg(Runner):
                 (_("RPG_RT"), "RPG_RT"),
                 (_("RPG_RT+"), "RPG_RT+"),
             ],
-            "default": ""
+            "default": "",
         },
         {
             "option": "seed",
@@ -253,13 +249,10 @@ class easyrpg(Runner):
             "advanced": True,
             "section": _("Engine"),
             "label": _("RNG seed"),
-            "help": _(
-                "Seeds the random number generator.\n"
-                "Use -1 to disable."
-            ),
+            "help": _("Seeds the random number generator.\n" "Use -1 to disable."),
             "min": -1,
             "max": 2147483647,
-            "default": -1
+            "default": -1,
         },
         {
             "option": "audio",
@@ -267,7 +260,7 @@ class easyrpg(Runner):
             "section": _("Audio"),
             "label": _("Enable audio"),
             "help": _("Switch off to disable audio."),
-            "default": True
+            "default": True,
         },
         {
             "option": "music_volume",
@@ -277,7 +270,7 @@ class easyrpg(Runner):
             "help": _("Volume of the background music."),
             "min": 0,
             "max": 100,
-            "default": 100
+            "default": 100,
         },
         {
             "option": "sound_volume",
@@ -287,7 +280,7 @@ class easyrpg(Runner):
             "help": _("Volume of the sound effects."),
             "min": 0,
             "max": 100,
-            "default": 100
+            "default": 100,
         },
         {
             "option": "soundfont",
@@ -295,7 +288,7 @@ class easyrpg(Runner):
             "advanced": True,
             "section": _("Audio"),
             "label": _("Soundfont"),
-            "help": _("Soundfont in sf2 format to use when playing MIDI files.")
+            "help": _("Soundfont in sf2 format to use when playing MIDI files."),
         },
         {
             "option": "fullscreen",
@@ -303,7 +296,7 @@ class easyrpg(Runner):
             "section": _("Graphics"),
             "label": _("Fullscreen"),
             "help": _("Start in fullscreen mode."),
-            "default": False
+            "default": False,
         },
         {
             "option": "game_resolution",
@@ -312,15 +305,14 @@ class easyrpg(Runner):
             "advanced": True,
             "label": _("Game resolution"),
             "help": _(
-                "Force a different game resolution.\n\n"
-                "This is experimental and can cause glitches or break games!"
+                "Force a different game resolution.\n\n" "This is experimental and can cause glitches or break games!"
             ),
             "choices": [
                 (_("320×240 (4:3, Original)"), "original"),
                 (_("416×240 (16:9, Widescreen)"), "widescreen"),
                 (_("560×240 (21:9, Ultrawide)"), "ultrawide"),
             ],
-            "default": "original"
+            "default": "original",
         },
         {
             "option": "scaling",
@@ -338,7 +330,7 @@ class easyrpg(Runner):
                 (_("Integer"), "integer"),
                 (_("Bilinear"), "bilinear"),
             ],
-            "default": "bilinear"
+            "default": "bilinear",
         },
         {
             "option": "stretch",
@@ -346,7 +338,7 @@ class easyrpg(Runner):
             "section": _("Graphics"),
             "label": _("Stretch"),
             "help": _("Ignore the aspect ratio and stretch video output to the entire width of the screen."),
-            "default": False
+            "default": False,
         },
         {
             "option": "vsync",
@@ -354,7 +346,7 @@ class easyrpg(Runner):
             "section": _("Graphics"),
             "label": _("Enable VSync"),
             "help": _("Switch off to disable VSync and use the FPS limit."),
-            "default": True
+            "default": True,
         },
         {
             "option": "fps_limit",
@@ -368,7 +360,7 @@ class easyrpg(Runner):
             ),
             "min": 0,
             "max": 9999,
-            "default": 60
+            "default": 60,
         },
         {
             "option": "show_fps",
@@ -381,7 +373,7 @@ class easyrpg(Runner):
                 (_("Fullscreen & title bar"), "on"),
                 (_("Fullscreen, title bar & window"), "full"),
             ],
-            "default": "off"
+            "default": "off",
         },
         {
             "option": "rtp",
@@ -389,34 +381,28 @@ class easyrpg(Runner):
             "section": _("Runtime Package"),
             "label": _("Enable RTP"),
             "help": _("Switch off to disable support for the Runtime Package (RTP)."),
-            "default": True
+            "default": True,
         },
         {
             "option": "rpg2k_rtp_path",
             "type": "directory_chooser",
             "section": _("Runtime Package"),
             "label": _("RPG2000 RTP location"),
-            "help": _(
-                "Full path to a directory containing an extracted "
-                "RPG Maker 2000 Run-Time-Package (RTP)."
-            )
+            "help": _("Full path to a directory containing an extracted " "RPG Maker 2000 Run-Time-Package (RTP)."),
         },
         {
             "option": "rpg2k3_rtp_path",
             "type": "directory_chooser",
             "section": _("Runtime Package"),
             "label": _("RPG2003 RTP location"),
-            "help": _(
-                "Full path to a directory containing an extracted "
-                "RPG Maker 2003 Run-Time-Package (RTP)."
-            )
+            "help": _("Full path to a directory containing an extracted " "RPG Maker 2003 Run-Time-Package (RTP)."),
         },
         {
             "option": "rpg_rtp_path",
             "type": "directory_chooser",
             "section": _("Runtime Package"),
             "label": _("Fallback RTP location"),
-            "help": _("Full path to a directory containing a combined RTP.")
+            "help": _("Full path to a directory containing a combined RTP."),
         },
     ]
 
@@ -546,7 +532,7 @@ class easyrpg(Runner):
             cmd.extend(("--engine", engine))
 
         patches = self.game_config.get("patches")
-        if patches == 'none':
+        if patches == "none":
             cmd.append("--no-patch")
         elif patches:
             cmd.extend(("--patches", *patches.split()))
