@@ -1,23 +1,37 @@
 """Wine runner"""
+
 # pylint: disable=too-many-lines
 import os
 import shlex
 from gettext import gettext as _
-from typing import Dict, Tuple
+from typing import Any, Dict, List, Optional, Tuple
 
 from lutris import runtime, settings
-from lutris.api import format_runner_version
+from lutris.api import format_runner_version, normalize_version_architecture
 from lutris.config import LutrisConfig
 from lutris.database.games import get_game_by_field
 from lutris.exceptions import (
-    EsyncLimitError, FsyncUnsupportedError, MisconfigurationError, MissingExecutableError, MissingGameExecutableError,
-    UnspecifiedVersionError
+    EsyncLimitError,
+    FsyncUnsupportedError,
+    MisconfigurationError,
+    MissingExecutableError,
+    MissingGameExecutableError,
+    UnspecifiedVersionError,
 )
 from lutris.game import Game
 from lutris.gui.dialogs import FileDialog
 from lutris.runners.commands.wine import (  # noqa: F401 pylint: disable=unused-import
-    create_prefix, delete_registry_key, eject_disc, install_cab_component, open_wine_terminal, set_regedit,
-    set_regedit_file, winecfg, wineexec, winekill, winetricks
+    create_prefix,
+    delete_registry_key,
+    eject_disc,
+    install_cab_component,
+    open_wine_terminal,
+    set_regedit,
+    set_regedit_file,
+    winecfg,
+    wineexec,
+    winekill,
+    winetricks,
 )
 from lutris.runners.runner import Runner
 from lutris.util import system
@@ -25,8 +39,8 @@ from lutris.util.display import DISPLAY_MANAGER, get_default_dpi
 from lutris.util.graphics import drivers, vkquery
 from lutris.util.linux import LINUX_SYSTEM
 from lutris.util.log import logger
-from lutris.util.steam.config import get_steam_dir
 from lutris.util.strings import split_arguments
+from lutris.util.wine import proton
 from lutris.util.wine.d3d_extras import D3DExtrasManager
 from lutris.util.wine.dgvoodoo2 import dgvoodoo2Manager
 from lutris.util.wine.dxvk import REQUIRED_VULKAN_API_VERSION, DXVKManager
@@ -35,55 +49,80 @@ from lutris.util.wine.extract_icon import PEFILE_AVAILABLE, ExtractIcon
 from lutris.util.wine.prefix import DEFAULT_DLL_OVERRIDES, WinePrefixManager, find_prefix
 from lutris.util.wine.vkd3d import VKD3DManager
 from lutris.util.wine.wine import (
-    WINE_DEFAULT_ARCH, WINE_DIR, WINE_PATHS, detect_arch, get_default_wine_runner_version_info,
-    get_default_wine_version, get_installed_wine_versions, get_overrides_env, get_proton_paths, get_real_executable,
-    get_system_wine_version, get_wine_path_for_version, is_esync_limit_set, is_fsync_supported, is_gstreamer_build
+    WINE_DEFAULT_ARCH,
+    WINE_DIR,
+    WINE_PATHS,
+    detect_arch,
+    get_default_wine_runner_version_info,
+    get_default_wine_version,
+    get_installed_wine_versions,
+    get_overrides_env,
+    get_real_executable,
+    get_system_wine_version,
+    get_wine_path_for_version,
+    is_esync_limit_set,
+    is_fsync_supported,
+    is_gstreamer_build,
 )
 
 
-def _get_prefix_warning(config, _option_key):
-    if config.get("prefix"):
+def _get_version_warning(config: LutrisConfig, _option_key: str) -> Optional[str]:
+    arch = config.game_config.get("arch")
+    version = config.runner_config.get("version")
+    if arch == "win32" and proton.is_proton_version(version):
+        return _("Proton is not compatible with 32-bit prefixes.")
+
+    return None
+
+
+def _get_prefix_warning(config: LutrisConfig, _option_key: str) -> Optional[str]:
+    game_config = config.game_config
+    if game_config.get("prefix"):
         return None
 
-    exe = config.get("exe")
+    exe = game_config.get("exe")
     if exe and find_prefix(exe):
         return None
 
     return _("<b>Warning</b> Some Wine configuration options cannot be applied, if no prefix can be found.")
 
 
-def _get_dxvk_warning(config, option_key):
+def _get_dxvk_warning(_config: LutrisConfig, _option_key: str) -> Optional[str]:
     if drivers.is_outdated():
         driver_info = drivers.get_nvidia_driver_info()
-        return _("<b>Warning</b> Your NVIDIA driver is outdated.\n"
-                 "You are currently running driver %s which does not "
-                 "fully support all features for Vulkan and DXVK games."
-                 ) % (
-            driver_info["nvrm"]["version"],
+        return _(
+            "<b>Warning</b> Your NVIDIA driver is outdated.\n"
+            "You are currently running driver %s which does not "
+            "fully support all features for Vulkan and DXVK games."
+        ) % (driver_info["version"],)
+
+    return None
+
+
+def _get_simple_vulkan_support_error(config: LutrisConfig, option_key: str, feature: str) -> Optional[str]:
+    if os.environ.get("LUTRIS_NO_VKQUERY"):
+        return None
+    if config.runner_config.get(option_key) and not LINUX_SYSTEM.is_vulkan_supported():
+        return (
+            _("<b>Error</b> Vulkan is not installed or is not supported by your system, " "%s is not available.")
+            % feature
         )
-
     return None
 
 
-def _get_simple_vulkan_support_error(config, option_key, feature):
-    if config.get(option_key) and not LINUX_SYSTEM.is_vulkan_supported():
-        return _("<b>Error</b> Vulkan is not installed or is not supported by your system, "
-                 "%s is not available.") % feature
-    return None
-
-
-def _get_dxvk_version_warning(config, _option_key):
-    if config.get("dxvk") and LINUX_SYSTEM.is_vulkan_supported():
-        version = config.get("dxvk_version")
+def _get_dxvk_version_warning(config: LutrisConfig, _option_key: str) -> Optional[str]:
+    if os.environ.get("LUTRIS_NO_VKQUERY"):
+        return None
+    runner_config = config.runner_config
+    if runner_config.get("dxvk") and LINUX_SYSTEM.is_vulkan_supported():
+        version = runner_config.get("dxvk_version")
         if version and not version.startswith("v1."):
             library_api_version = vkquery.get_vulkan_api_version()
             if library_api_version and library_api_version < REQUIRED_VULKAN_API_VERSION:
-                return _("<b>Warning</b> Lutris has detected that Vulkan API version %s is installed, "
-                         "but to use the latest DXVK version, %s is required."
-                         ) % (
-                    vkquery.format_version(library_api_version),
-                    vkquery.format_version(REQUIRED_VULKAN_API_VERSION)
-                )
+                return _(
+                    "<b>Warning</b> Lutris has detected that Vulkan API version %s is installed, "
+                    "but to use the latest DXVK version, %s is required."
+                ) % (vkquery.format_version(library_api_version), vkquery.format_version(REQUIRED_VULKAN_API_VERSION))
 
             devices = vkquery.get_device_info()
 
@@ -94,34 +133,37 @@ def _get_dxvk_version_warning(config, _option_key):
                 ) % (
                     devices[0].name,
                     vkquery.format_version(devices[0].api_version),
-                    vkquery.format_version(REQUIRED_VULKAN_API_VERSION)
+                    vkquery.format_version(REQUIRED_VULKAN_API_VERSION),
                 )
 
     return None
 
 
-def _get_esync_warning(config, _option_key):
-    if config.get("esync"):
+def _get_esync_warning(config: LutrisConfig, _option_key: str) -> Optional[str]:
+    if config.runner_config.get("esync"):
         limits_set = is_esync_limit_set()
         if not limits_set:
-            return _("<b>Warning</b> Your limits are not set correctly. Please increase them as described here:\n"
-                     "<a href='https://github.com/lutris/docs/blob/master/HowToEsync.md'>"
-                     "How-to-Esync (https://github.com/lutris/docs/blob/master/HowToEsync.md)</a>")
+            return _(
+                "<b>Warning</b> Your limits are not set correctly. Please increase them as described here:\n"
+                "<a href='https://github.com/lutris/docs/blob/master/HowToEsync.md'>"
+                "How-to-Esync (https://github.com/lutris/docs/blob/master/HowToEsync.md)</a>"
+            )
     return ""
 
 
-def _get_fsync_warning(config, _option_key):
-    if config.get("fsync"):
+def _get_fsync_warning(config: LutrisConfig, _option_key: str) -> Optional[str]:
+    if config.runner_config.get("fsync"):
         fsync_supported = is_fsync_supported()
         if not fsync_supported:
             return _("<b>Warning</b> Your kernel is not patched for fsync.")
-        return ""
+    return None
 
 
-def _get_virtual_desktop_warning(config, _option_key):
+def _get_virtual_desktop_warning(config: LutrisConfig, _option_key: str) -> Optional[str]:
     message = _("Wine virtual desktop is no longer supported")
-    if config.get("Desktop"):
-        version = str(config.get("version")).casefold()
+    runner_config = config.runner_config
+    if runner_config.get("Desktop"):
+        version = str(runner_config.get("version")).casefold()
         if "-ge-" in version or "proton" in version:
             message += "\n"
             message += _("Virtual desktops cannot be enabled in Proton or GE Wine versions.")
@@ -147,7 +189,7 @@ class wine(Runner):
             "type": "string",
             "label": _("Arguments"),
             "help": _("Windows command line arguments used when launching the game"),
-            "validator": shlex.split
+            "validator": shlex.split,
         },
         {
             "option": "working_dir",
@@ -165,7 +207,7 @@ class wine(Runner):
             "label": _("Wine prefix"),
             "warning": _get_prefix_warning,
             "help": _(
-                'The prefix used by Wine.\n'
+                "The prefix used by Wine.\n"
                 "It's a directory containing a set of files and "
                 "folders making up a confined Windows environment."
             ),
@@ -186,7 +228,7 @@ class wine(Runner):
         "MouseWarpOverride": r"%s/DirectInput" % reg_prefix,
         "Desktop": "MANAGED",
         "WineDesktop": "MANAGED",
-        "ShowCrashDialog": "MANAGED"
+        "ShowCrashDialog": "MANAGED",
     }
 
     core_processes = (
@@ -231,6 +273,7 @@ class wine(Runner):
                 "type": "choice",
                 "choices": get_wine_version_choices,
                 "default": get_default_wine_version,
+                "warning": _get_version_warning,
                 "help": _(
                     "The version of Wine used to launch the game.\n"
                     "Using the last version is generally recommended, "
@@ -242,8 +285,7 @@ class wine(Runner):
                 "label": _("Custom Wine executable"),
                 "type": "file",
                 "advanced": True,
-                "help": _("The Wine executable to be used if you have "
-                          'selected "Custom" as the Wine version.'),
+                "help": _("The Wine executable to be used if you have " 'selected "Custom" as the Wine version.'),
             },
             {
                 "option": "system_winetricks",
@@ -265,7 +307,8 @@ class wine(Runner):
                 "help": _(
                     "Use DXVK to "
                     "increase compatibility and performance in Direct3D 11, 10 "
-                    "and 9 applications by translating their calls to Vulkan."),
+                    "and 9 applications by translating their calls to Vulkan."
+                ),
             },
             {
                 "option": "dxvk_version",
@@ -278,7 +321,6 @@ class wine(Runner):
                 "default": DXVKManager().version,
                 "warning": _get_dxvk_version_warning,
             },
-
             {
                 "option": "vkd3d",
                 "section": _("Graphics"),
@@ -288,8 +330,8 @@ class wine(Runner):
                 "default": True,
                 "active": True,
                 "help": _(
-                    "Use VKD3D to enable support for Direct3D 12 "
-                    "applications by translating their calls to Vulkan."),
+                    "Use VKD3D to enable support for Direct3D 12 " "applications by translating their calls to Vulkan."
+                ),
             },
             {
                 "option": "vkd3d_version",
@@ -330,9 +372,7 @@ class wine(Runner):
                 "error": lambda c, k: _get_simple_vulkan_support_error(c, k, _("DXVK-NVAPI / DLSS")),
                 "default": True,
                 "advanced": True,
-                "help": _(
-                    "Enable emulation of Nvidia's NVAPI and add DLSS support, if available."
-                ),
+                "help": _("Enable emulation of Nvidia's NVAPI and add DLSS support, if available."),
             },
             {
                 "option": "dxvk_nvapi_version",
@@ -524,8 +564,7 @@ class wine(Runner):
                     (_("Full (CAUTION: Will cause MASSIVE slowdown)"), "+all"),
                 ],
                 "default": "-all",
-                "help": _("Output debugging information in the game log "
-                          "(might affect performance)"),
+                "help": _("Output debugging information in the game log " "(might affect performance)"),
             },
             {
                 "option": "ShowCrashDialog",
@@ -540,9 +579,9 @@ class wine(Runner):
                 "label": _("Autoconfigure joypads"),
                 "advanced": True,
                 "default": False,
-                "help":
-                    _("Automatically disables one of Wine's detected joypad "
-                      "to avoid having 2 controllers detected"),
+                "help": _(
+                    "Automatically disables one of Wine's detected joypad " "to avoid having 2 controllers detected"
+                ),
             },
             {
                 "option": "sandbox",
@@ -654,7 +693,7 @@ class wine(Runner):
                 arch = WINE_DEFAULT_ARCH
         return arch
 
-    def get_runner_version(self, version: str = None) -> Dict[str, str]:
+    def get_runner_version(self, version: str = None) -> Optional[Dict[str, str]]:
         if not version:
             default_version_info = get_default_wine_runner_version_info()
             default_version = format_runner_version(default_version_info) if default_version_info else None
@@ -697,8 +736,8 @@ class wine(Runner):
         resolved = super().resolve_config_path(path, relative_to)
         resolved = system.fix_path_case(resolved)
 
-        if not os.path.exists(resolved) and '\\' in path:
-            fixed = path.replace('\\', '/')
+        if not os.path.exists(resolved) and "\\" in path:
+            fixed = path.replace("\\", "/")
             fixed_resolved = super().resolve_config_path(fixed, relative_to)
             fixed_resolved = system.fix_path_case(fixed_resolved)
             return fixed_resolved
@@ -712,9 +751,15 @@ class wine(Runner):
         if version is None:
             version = self.read_version_from_config()
 
-        wine_path = self.get_path_for_version(version)
-        if system.path_exists(wine_path):
-            return wine_path
+        if proton.is_proton_version(version):
+            return proton.get_proton_wine_path(version)
+        try:
+            wine_path = self.get_path_for_version(version)
+            if system.path_exists(wine_path):
+                return wine_path
+        except MissingExecutableError:
+            if not fallback:
+                raise
 
         if not fallback:
             raise MissingExecutableError(_("The Wine executable at '%s' is missing.") % wine_path)
@@ -735,6 +780,17 @@ class wine(Runner):
             # which one to get the correct LutrisConfig object.
         return wine_path
 
+    def get_command(self) -> List[str]:
+        command = super().get_command()
+        if command:
+            if proton.is_proton_path(command[0]) and not proton.is_umu_path(command[0]):
+                command[0] = proton.get_umu_path()
+
+            if proton.is_umu_path(command[0]) and self.wine_arch == "win32":
+                raise RuntimeError(_("Proton is not compatible with 32-bit prefixes."))
+
+        return command
+
     def is_installed(self, flatpak_allowed: bool = True, version: str = None, fallback: bool = True) -> bool:
         """Check if Wine is installed.
         If no version is passed, checks if any version of wine is available
@@ -756,19 +812,21 @@ class wine(Runner):
         except MisconfigurationError:
             return False
 
-    def get_installer_runner_version(self, installer, use_runner_config: bool = True, use_api: bool = False) -> str:
+    def get_installer_runner_version(
+        self, installer, use_runner_config: bool = True, use_api: bool = False
+    ) -> Optional[str]:
         # If a version is specified in the script choose this one
         version = None
         if installer.script.get(installer.runner):
             version = installer.script[installer.runner].get("version")
+            version = normalize_version_architecture(version)
         # If the installer is an extension, use the wine version from the base game
         elif installer.requires:
             db_game = get_game_by_field(installer.requires, field="installer_slug")
             if not db_game:
                 db_game = get_game_by_field(installer.requires, field="slug")
             if not db_game:
-                raise MisconfigurationError(
-                    _("The required game '%s' could not be found.") % installer.requires)
+                raise MisconfigurationError(_("The required game '%s' could not be found.") % installer.requires)
             game = Game(db_game["id"])
             version = game.config.runner_config["version"]
 
@@ -777,20 +835,22 @@ class wine(Runner):
             try:
                 return wine.get_runner_version_and_config()[0]
             except UnspecifiedVersionError:
-                pass  # prefer the error message below for this
+                pass  # fall back to the API in this case
 
         if not version and use_api:
             # Try to obtain the default wine version from the Lutris API.
             default_version_info = self.get_runner_version()
-            if "version" in default_version_info:
+            if default_version_info and "version" in default_version_info:
                 logger.debug("Default wine version is %s", default_version_info["version"])
                 version = format_runner_version(default_version_info)
 
-        if not version:
-            raise UnspecifiedVersionError(_("The installer does not specify a Wine version."))
-
         return version
 
+    def adjust_installer_runner_config(self, installer_runner_config: Dict[str, Any]) -> None:
+        version = installer_runner_config.get("version")
+        if version:
+            installer_runner_config["version"] = normalize_version_architecture(version)
+
     @classmethod
     def get_runner_version_and_config(cls) -> Tuple[str, LutrisConfig]:
         runner_config = LutrisConfig(runner_slug="wine")
@@ -832,7 +892,7 @@ class wine(Runner):
             working_dir=self.prefix_path,
             config=self,
             env=self.get_env(os_env=True),
-            runner=self
+            runner=self,
         )
 
     def run_wineexec(self, *args):
@@ -858,7 +918,7 @@ class wine(Runner):
             arch=self.wine_arch,
             config=self,
             env=self.get_env(os_env=True),
-            runner=self
+            runner=self,
         )
 
     def run_regedit(self, *args):
@@ -894,7 +954,7 @@ class wine(Runner):
             disable_runtime=disable_runtime,
             system_winetricks=system_winetricks,
             env=self.get_env(os_env=True, disable_runtime=disable_runtime),
-            runner=self
+            runner=self,
         )
 
     def run_winecpl(self, *args):
@@ -909,6 +969,7 @@ class wine(Runner):
 
     def run_winekill(self, *args):
         """Runs wineserver -k."""
+
         winekill(
             self.prefix_path,
             arch=self.wine_arch,
@@ -937,9 +998,13 @@ class wine(Runner):
                     # Do not pass fallback 'auto' value to managed keys
                     if value == "auto":
                         value = None
-                    if value and key in ("Desktop", "WineDesktop") and (
-                        "wine-ge" in self.get_executable().lower()
-                        or "proton" in self.get_executable().lower()
+                    if (
+                        value
+                        and key in ("Desktop", "WineDesktop")
+                        and (
+                            "wine-ge" in self.get_executable().casefold()
+                            or proton.is_proton_path(self.get_executable())
+                        )
                     ):
                         logger.warning("Wine Virtual Desktop can't be used with Wine-GE and Proton")
                         value = None
@@ -1000,7 +1065,7 @@ class wine(Runner):
             (VKD3DManager, "vkd3d", "vkd3d_version"),
             (DXVKNVAPIManager, "dxvk_nvapi", "dxvk_nvapi_version"),
             (D3DExtrasManager, "d3d_extras", "d3d_extras_version"),
-            (dgvoodoo2Manager, "dgvoodoo2", "dgvoodoo2_version")
+            (dgvoodoo2Manager, "dgvoodoo2", "dgvoodoo2_version"),
         ]
 
         managers = {}
@@ -1008,11 +1073,7 @@ class wine(Runner):
             enabled = bool(self.runner_config.get(enabled_option))
             version = self.runner_config.get(version_option)
             if enabled or not enabled_only:
-                manager = manager_class(
-                    self.prefix_path,
-                    arch=self.wine_arch,
-                    version=version
-                )
+                manager = manager_class(self.prefix_path, arch=self.wine_arch, version=version)
 
                 if not manager.can_enable():
                     enabled = False
@@ -1044,18 +1105,22 @@ class wine(Runner):
         if show_debug != "inherit":
             env["WINEDEBUG"] = show_debug
         if show_debug == "-all":
-            env["DXVK_LOG_LEVEL"] = "none"
+            env["DXVK_LOG_LEVEL"] = "debug"
+            env["UMU_LOG"] = "debug"
         env["WINEARCH"] = self.wine_arch
         wine_exe = self.get_executable()
         wine_config_version = self.read_version_from_config()
         env["WINE"] = wine_exe
         env["WINE_MONO_CACHE_DIR"] = os.path.join(WINE_DIR, wine_config_version, "mono")
         env["WINE_GECKO_CACHE_DIR"] = os.path.join(WINE_DIR, wine_config_version, "gecko")
-        if is_gstreamer_build(wine_exe):
+
+        # We don't want to override gstreamer for proton, it has it's own version
+        if not proton.is_proton_path(wine_exe) and is_gstreamer_build(wine_exe):
             path_64 = os.path.join(WINE_DIR, wine_config_version, "lib64/gstreamer-1.0/")
             path_32 = os.path.join(WINE_DIR, wine_config_version, "lib/gstreamer-1.0/")
             if os.path.exists(path_64) or os.path.exists(path_32):
                 env["GST_PLUGIN_SYSTEM_PATH_1_0"] = path_64 + ":" + path_32
+
         if self.prefix_path:
             env["WINEPREFIX"] = self.prefix_path
 
@@ -1078,6 +1143,9 @@ class wine(Runner):
         if self.runner_config.get("eac"):
             env["PROTON_EAC_RUNTIME"] = os.path.join(settings.RUNTIME_DIR, "eac_runtime")
 
+        if not self.runner_config.get("dxvk") or not LINUX_SYSTEM.is_vulkan_supported():
+            env["PROTON_USE_WINED3D"] = "1"
+
         for dll_manager in self.get_dll_managers(enabled_only=True):
             self.dll_overrides.update(dll_manager.get_enabling_dll_overrides())
 
@@ -1087,32 +1155,21 @@ class wine(Runner):
 
         env["WINEDLLOVERRIDES"] = get_overrides_env(self.dll_overrides)
 
-        # Proton support
-        if wine_config_version and "Proton" in wine_config_version:
-            steam_dir = get_steam_dir()
-            if steam_dir:  # May be None for example if Proton-GE is used but Steam is not installed
-                env["STEAM_COMPAT_CLIENT_INSTALL_PATH"] = steam_dir
-
-            prefix_path = self.prefix_path
-            if prefix_path:
-                env["STEAM_COMPAT_DATA_PATH"] = prefix_path
-
-            env["STEAM_COMPAT_APP_ID"] = '0'
-            env["SteamAppId"] = '0'
-            if "SteamGameId" not in env:
-                env["SteamGameId"] = "lutris-game"
         return env
 
+    def finish_env(self, env: Dict[str, str], game) -> None:
+        super().finish_env(env, game)
+
+        wine_exe = self.get_executable()
+
+        if proton.is_proton_path(wine_exe):
+            game_id = proton.get_game_id(game, env)
+            proton.update_proton_env(wine_exe, env, game_id=game_id)
+
     def get_runtime_env(self):
         """Return runtime environment variables with path to wine for Lutris builds"""
-        wine_path = None
         try:
-            exe = self.get_executable()
-            if WINE_DIR:
-                wine_path = os.path.dirname(os.path.dirname(exe))
-            for proton_path in get_proton_paths():
-                if proton_path in exe:
-                    wine_path = os.path.dirname(os.path.dirname(exe))
+            wine_path = os.path.dirname(os.path.dirname(self.get_executable()))
         except MisconfigurationError:
             wine_path = None
 
@@ -1128,9 +1185,11 @@ class wine(Runner):
             exe = wine_path or self.get_executable()
         except MisconfigurationError:
             return set()
-
+        if proton.is_proton_path(exe):
+            logger.debug("Tracking PIDs of Proton games is not possible at the moment")
+            return set()
         if not exe.startswith("/"):
-            exe = system.find_executable(exe)
+            exe = system.find_required_executable(exe)
         pids = system.get_pids_using_file(exe)
         if self.wine_arch == "win64" and os.path.basename(exe) == "wine":
             pids = pids | system.get_pids_using_file(exe + "64")
@@ -1154,10 +1213,10 @@ class wine(Runner):
         game_exe = self.game_exe
         arguments = self.game_config.get("args", "")
         launch_info = {"env": self.get_env(os_env=False)}
-        using_dxvk = self.runner_config.get("dxvk")
+        using_dxvk = self.runner_config.get("dxvk") and LINUX_SYSTEM.is_vulkan_supported
 
         if using_dxvk:
-            # Set this to 1 to enable access to more RAM for 32bit applications
+            # Set this to 1 to enable access to more RAM for 32-bit applications
             launch_info["env"]["WINE_LARGE_ADDRESS_AWARE"] = "1"
 
         if not game_exe or not system.path_exists(game_exe):
@@ -1167,13 +1226,13 @@ class wine(Runner):
             limit_set = is_esync_limit_set()
 
             if not limit_set:
-                raise EsyncLimitError(_("Your ESYNC limits are not set correctly."))
+                raise EsyncLimitError()
 
         if launch_info["env"].get("WINEFSYNC") == "1":
             fsync_supported = is_fsync_supported()
 
             if not fsync_supported:
-                raise FsyncUnsupportedError(_("Your kernel is not patched for fsync."))
+                raise FsyncUnsupportedError()
 
         command = self.get_command()
 
@@ -1193,38 +1252,23 @@ class wine(Runner):
         alive for some reason, but the caller will detect this and SIGKILL it."""
         self.run_winekill()
 
-    @staticmethod
-    def parse_wine_path(path, prefix_path=None):
-        """Take a Windows path, return the corresponding Linux path."""
-        if not prefix_path:
-            prefix_path = os.path.expanduser("~/.wine")
-
-        path = path.replace("\\\\", "/").replace("\\", "/")
-
-        if path[1] == ":":  # absolute path
-            drive = os.path.join(prefix_path, "dosdevices", path[:2].lower())
-            if os.path.islink(drive):  # Try to resolve the path
-                drive = os.readlink(drive)
-            return os.path.join(drive, path[3:])
-
-        if path[0] == "/":  # drive-relative path. C is as good a guess as any..
-            return os.path.join(prefix_path, "drive_c", path[1:])
-
-        # Relative path
-        return path
-
     def extract_icon(self, game_slug):
         """Extracts the 128*128 icon from EXE and saves it, if not resizes the biggest icon found.
         returns true if an icon is saved, false if not"""
+
         try:
             wantedsize = (128, 128)
             pathtoicon = settings.ICON_PATH + "/lutris_" + game_slug + ".png"
-            if not self.game_exe or os.path.exists(pathtoicon) or not PEFILE_AVAILABLE:
+            exe = self.game_exe
+            if not exe or os.path.exists(pathtoicon) or not PEFILE_AVAILABLE:
                 return False
 
             extractor = ExtractIcon(self.game_exe)
             groups = extractor.get_group_icons()
 
+            if not groups:
+                return False
+
             icons = []
             biggestsize = (0, 0)
             biggesticon = -1
@@ -1241,7 +1285,7 @@ class wine(Runner):
                 resized = icons[biggesticon].resize(wantedsize)
                 resized.save(pathtoicon)
                 return True
-        except Exception as err:
-            logger.exception("Failed to extract exe icon: %s", err)
-
-        return False
+            return False
+        except Exception as ex:
+            logger.exception("Unable to extract icon from %s: %s", exe, ex)
+            return False
