@@ -5,6 +5,7 @@ import os
 import random
 import ssl
 from gettext import gettext as _
+from typing import Any, Dict, Optional
 from xml.etree import ElementTree
 
 import requests
@@ -16,7 +17,7 @@ from lutris.config import LutrisConfig, write_game_config
 from lutris.database.games import add_game, get_game_by_field
 from lutris.database.services import ServiceGameCollection
 from lutris.game import Game
-from lutris.services.base import OnlineService
+from lutris.services.base import SERVICE_LOGIN, OnlineService
 from lutris.services.lutris import sync_media
 from lutris.services.service_game import ServiceGame
 from lutris.services.service_media import ServiceMedia
@@ -62,8 +63,18 @@ class EAAppArtSmall(ServiceMedia):
     dest_path = os.path.join(settings.CACHE_DIR, "ea_app/pack-art-small")
     api_field = "packArtSmall"
 
-    def get_media_url(self, details):
-        return details["imageServer"] + details["i18n"][self.api_field]
+    def get_media_url(self, details: Dict[str, Any]) -> Optional[str]:
+        if "imageServer" not in details:
+            logger.warning("No field 'imageServer' in API game %s", details)
+            return None
+        if "i18n" not in details:
+            logger.warning("No field 'i18n' in API game %s", details)
+            return None
+        i18n = details["i18n"]
+        if self.api_field not in i18n:
+            logger.warning("No field 'i18n.%s' in API game %s", self.api_field, details)
+            return None
+        return details["imageServer"] + i18n[self.api_field]
 
 
 class EAAppArtMedium(EAAppArtSmall):
@@ -157,7 +168,7 @@ class EAAppService(OnlineService):
         "&locale=en_US&release_type=prod"
         "&redirect_uri=%s"
     ) % origin_redirect_uri
-    login_user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:100.0) Gecko/20100101 Firefox/100.0 QtWebEngine/5.8.0"
+    login_user_agent = settings.DEFAULT_USER_AGENT + " QtWebEngine/5.8.0"
 
     def __init__(self):
         super().__init__()
@@ -175,7 +186,7 @@ class EAAppService(OnlineService):
 
     def login_callback(self, url):
         self.fetch_access_token()
-        self.emit("service-login")
+        SERVICE_LOGIN.fire(self)
 
     def fetch_access_token(self):
         token_data = self.get_access_token()
