@@ -1,18 +1,17 @@
 """Utilities for manipulating Wine"""
+
 import os
 from collections import OrderedDict
 from gettext import gettext as _
-from typing import Dict, Generator, List, Tuple
+from typing import Dict, List, Tuple
 
 from lutris import settings
-from lutris.api import get_default_runner_version_info
+from lutris.api import get_default_wine_runner_version_info
 from lutris.exceptions import MisconfigurationError, UnavailableRunnerError, UnspecifiedVersionError
-from lutris.gui.dialogs import ErrorDialog
 from lutris.util import cache_single, linux, system
 from lutris.util.log import logger
-from lutris.util.steam.config import get_steamapps_dirs
-from lutris.util.strings import parse_version
-from lutris.util.wine import fsync
+from lutris.util.strings import get_natural_sort_key, parse_version
+from lutris.util.wine import fsync, proton
 
 WINE_DIR: str = os.path.join(settings.RUNNER_DIR, "wine")
 WINE_DEFAULT_ARCH: str = "win64" if linux.LINUX_SYSTEM.is_64_bit else "win32"
@@ -25,51 +24,25 @@ WINE_PATHS: Dict[str, str] = {
 
 # Insert additional system-wide Wine installations.
 try:
-    for _candidate in os.listdir('/usr/lib/'):
-        if _candidate.startswith("wine-"):
-            _wine_path = os.path.join("/usr/lib/", _candidate, "bin/wine")
-            if os.path.isfile(_wine_path):
-                WINE_PATHS["System " + _candidate] = _wine_path
+    if system.path_exists("/usr/lib"):
+        for _candidate in os.listdir("/usr/lib/"):
+            if _candidate.startswith("wine-"):
+                _wine_path = os.path.join("/usr/lib/", _candidate, "bin/wine")
+                if os.path.isfile(_wine_path):
+                    WINE_PATHS["System " + _candidate] = _wine_path
     _candidate = None
     _wine_path = None
 except Exception as ex:
     logger.exception("Unable to enumerate system Wine versions: %s", ex)
 
 
-def _iter_proton_locations() -> Generator[str, None, None]:
-    """Iterate through all existing Proton locations"""
-    try:
-        steamapp_dirs = get_steamapps_dirs()
-    except:
-        return  # in case of corrupt or unreadable Steam configuration files!
-
-    for path in [os.path.join(p, "common") for p in steamapp_dirs]:
-        if os.path.isdir(path):
-            yield path
-    for path in [os.path.join(p, "") for p in steamapp_dirs]:
-        if os.path.isdir(path):
-            yield path
-
-
-def get_proton_paths() -> List[str]:
-    """Get the Folder that contains all the Proton versions. Can probably be improved"""
-    paths = set()
-    for path in _iter_proton_locations():
-        proton_versions = [p for p in os.listdir(path) if "Proton" in p]
-        for version in proton_versions:
-            if system.path_exists(os.path.join(path, version, "dist/bin/wine")):
-                paths.add(path)
-            if system.path_exists(os.path.join(path, version, "files/bin/wine")):
-                paths.add(path)
-    return list(paths)
-
-
 def detect_arch(prefix_path: str = None, wine_path: str = None) -> str:
     """Given a Wine prefix path, return its architecture"""
+    if wine_path:
+        if proton.is_proton_path(wine_path) or system.path_exists(wine_path + "64"):
+            return "win64"
     if prefix_path and is_prefix_directory(prefix_path):
         return detect_prefix_arch(prefix_path)
-    if wine_path and system.path_exists(wine_path + "64"):
-        return "win64"
     return "win32"
 
 
@@ -91,7 +64,7 @@ def detect_prefix_arch(prefix_path: str) -> str:
 
     prefix_path = os.path.expanduser(prefix_path)
     registry_path = os.path.join(prefix_path, "system.reg")
-    with open(registry_path, "r", encoding='utf-8') as registry:
+    with open(registry_path, "r", encoding="utf-8") as registry:
         for _line_no in range(5):
             line = registry.readline()
             if "win64" in line:
@@ -132,11 +105,8 @@ def is_installed_systemwide() -> bool:
 
 def list_system_wine_versions() -> List[str]:
     """Return the list of wine versions installed on the system"""
-    return [
-        name
-        for name, path in WINE_PATHS.items()
-        if get_system_wine_version(path)
-    ]
+    versions = [name for name, path in WINE_PATHS.items() if get_system_wine_version(path)]
+    return sorted(versions, key=get_natural_sort_key, reverse=True)
 
 
 def list_lutris_wine_versions() -> List[str]:
@@ -151,29 +121,19 @@ def list_lutris_wine_versions() -> List[str]:
                 versions.append(dirname)
         except MisconfigurationError:
             pass  # if it's not properly installed, skip it
-    return versions
-
-
-def list_proton_versions() -> List[str]:
-    """Return the list of Proton versions installed in Steam"""
-    versions = []
-    for proton_path in get_proton_paths():
-        proton_versions = [p for p in os.listdir(proton_path) if "Proton" in p]
-        for version in proton_versions:
-            path = os.path.join(proton_path, version, "dist/bin/wine")
-            if os.path.isfile(path):
-                versions.append(version)
-            # Support Proton Experimental
-            path = os.path.join(proton_path, version, "files/bin/wine")
-            if os.path.isfile(path):
-                versions.append(version)
-    return versions
+    return sorted(versions, key=get_natural_sort_key, reverse=True)
 
 
 @cache_single
 def get_installed_wine_versions() -> List[str]:
     """Return the list of Wine versions installed"""
-    return list_system_wine_versions() + list_lutris_wine_versions() + list_proton_versions()
+    return list_system_wine_versions() + proton.list_proton_versions() + list_lutris_wine_versions()
+
+
+def clear_wine_version_cache() -> None:
+    get_installed_wine_versions.cache_clear()
+    proton.get_proton_versions.cache_clear()
+    proton.get_umu_path.cache_clear()
 
 
 def get_wine_path_for_version(version: str, config: dict = None) -> str:
@@ -186,13 +146,9 @@ def get_wine_path_for_version(version: str, config: dict = None) -> str:
         raise UnspecifiedVersionError(_("The Wine version must be specified."))
 
     if version in WINE_PATHS:
-        return system.find_executable(WINE_PATHS[version])
-    if "Proton" in version:
-        for proton_path in get_proton_paths():
-            if os.path.isfile(os.path.join(proton_path, version, "dist/bin/wine")):
-                return os.path.join(proton_path, version, "dist/bin/wine")
-            if os.path.isfile(os.path.join(proton_path, version, "files/bin/wine")):
-                return os.path.join(proton_path, version, "files/bin/wine")
+        return system.find_required_executable(WINE_PATHS[version])
+    if proton.is_proton_version(version):
+        return proton.get_proton_wine_path(version)
     if version == "custom":
         if config is None:
             raise RuntimeError("Custom wine paths are only supported when a configuration is available.")
@@ -208,6 +164,7 @@ def parse_wine_version(version: str) -> Tuple[List[int], str, str]:
     Wine versions for correct parsing."""
     version = version.replace("Proton7-", "Proton-7.")
     version = version.replace("Proton8-", "Proton-8.")
+    version = version.replace("Proton9-", "Proton-9.")
     return parse_version(version)
 
 
@@ -238,21 +195,14 @@ def get_default_wine_version() -> str:
     installed_versions = get_installed_wine_versions()
     if installed_versions:
         default_version = get_default_wine_runner_version_info()
-        if "version" in default_version and "architecture" in default_version:
-            version = default_version["version"] + '-' + default_version["architecture"]
+        if default_version and "version" in default_version and "architecture" in default_version:
+            version = default_version["version"] + "-" + default_version["architecture"]
             if version in installed_versions:
                 return version
         return installed_versions[0]
     raise UnavailableRunnerError(_("No versions of Wine are installed."))
 
 
-@cache_single
-def get_default_wine_runner_version_info():
-    """Just returns the runner info for the default Wine, but with
-    caching."""
-    return get_default_runner_version_info("wine")
-
-
 def get_system_wine_version(wine_path: str = "wine") -> str:
     """Return the version of Wine installed on the system."""
     if wine_path != "wine" and not system.path_exists(wine_path):
@@ -268,8 +218,7 @@ def get_system_wine_version(wine_path: str = "wine") -> str:
     return version
 
 
-def get_real_executable(windows_executable: str, working_dir: str) -> Tuple[
-        str, List[str], str]:
+def get_real_executable(windows_executable: str, working_dir: str) -> Tuple[str, List[str], str]:
     """Given a Windows executable, return the real program
     capable of launching it along with necessary arguments."""
 
@@ -290,30 +239,12 @@ def get_real_executable(windows_executable: str, working_dir: str) -> Tuple[
     return (windows_executable, [], working_dir)
 
 
-def esync_display_limit_warning(parent=None):
-    ErrorDialog(_(
-        "Your limits are not set correctly."
-        " Please increase them as described here:"
-        " <a href='https://github.com/lutris/docs/blob/master/HowToEsync.md'>"
-        "How-to:-Esync (https://github.com/lutris/docs/blob/master/HowToEsync.md)</a>"
-    ), parent=parent)
-
-
-def fsync_display_support_warning(parent=None):
-    ErrorDialog(_(
-        "Your kernel is not patched for fsync."
-        " Please get a patched kernel to use fsync."
-    ), parent=parent)
-
-
 def get_overrides_env(overrides: Dict[str, str]) -> str:
     """
     Output a string of dll overrides usable with WINEDLLOVERRIDES
     See: https://wiki.winehq.org/Wine_User%27s_Guide#WINEDLLOVERRIDES.3DDLL_Overrides
     """
-    default_overrides = {
-        "winemenubuilder": ""
-    }
+    default_overrides = {"winemenubuilder": ""}
     overrides.update(default_overrides)
     override_buckets = OrderedDict([("n,b", []), ("b,n", []), ("b", []), ("n", []), ("d", []), ("", [])])
     for dll, value in overrides.items():
